from distutils.core import setup

setup(
    name = 'data-lake-plan',
    packages = ['data-lake-plan'],
    version = '0.0.1',  # Ideally should be same as your GitHub release tag varsion
    description = 'data lake plan excel',
    author = '',
    author_email = '',
    url = 'https://github.com/musicnova/DataLakePlan',
    download_url = 'https://github.com/musicnova/DataLakePlan/archive/0.0.1.tar.gz',
    keywords = ['data', 'lake'],
    classifiers = [],
)



"""Excel module"""
 
def create_project():
    from openpyxl import Workbook
    wb = Workbook()

    # grab the active worksheet
    ws = wb.active

    # Data can be assigned directly to cells
    ws['A1'] = 42

    # Rows can also be appended
    ws.append([1, 2, 3])

    # Python types will automatically be converted
    import datetime
    ws['A2'] = datetime.datetime.now()

    # Save the file
    wb.save("sample.xlsx")

    # Debug output
    print("ok")

if __name__ == "__main__":
    import sys
    create_project()
